@@ -7,7 +7,7 @@ from spikesorters.tests.common_tests import SorterCommonTestSuite
 
 # This run several tests
 # @pytest.mark.skipif(True, reason='travis bug not fixed yet')
-@pytest.mark.skipif(not Mountainsort4Sorter.installed, reason='moutainsort4 not installed')
+@pytest.mark.skipif(not Mountainsort4Sorter.is_installed(), reason='moutainsort4 not installed')
 class Mountainsort4CommonTestSuite(SorterCommonTestSuite, unittest.TestCase):
     SorterClass = Mountainsort4Sorter
 
