@@ -10,7 +10,7 @@ from spikesorters import WaveClusSorter
 from spikesorters.tests.common_tests import SorterCommonTestSuite
 
 # This run several tests
-@pytest.mark.skipif(not WaveClusSorter.installed, reason='waveclus not installed')
+@pytest.mark.skipif(not WaveClusSorter.is_installed(), reason='waveclus not installed')
 class WaveClusCommonTestSuite(SorterCommonTestSuite, unittest.TestCase):
     SorterClass = WaveClusSorter
 
